@@ -95,7 +95,7 @@ bool ASGE::GLRenderer::init()
     return false;
   }
 
- // glfwWindowHint(GLFW_OPENGL_FORWARD_COMPAT, GL_TRUE);
+  glfwWindowHint(GLFW_OPENGL_FORWARD_COMPAT, GL_TRUE);
   glfwWindowHint(GLFW_OPENGL_PROFILE, GLFW_OPENGL_CORE_PROFILE);
   glfwWindowHint(GLFW_VISIBLE, GLFW_FALSE);
   glfwWindowHint(GLFW_SAMPLES, ASGE::SETTINGS.msaa_level);
@@ -140,7 +140,6 @@ bool ASGE::GLRenderer::init()
       updateMonitorInfo(glfwGetPrimaryMonitor());
       centerWindow();
       setWindowedMode(ASGE::SETTINGS.mode);
-      glfwGetFramebufferSize(window, &target_width, &target_height);
       glfwShowWindow(this->window);
       item.second();
       RENDER_LIB = sprite_renderer->getRenderLib();
@@ -148,7 +147,9 @@ bool ASGE::GLRenderer::init()
     }
   }
 
-  setProjectionMatrix(0, 0, static_cast<float>(target_width), static_cast<float>(target_height));
+  setProjectionMatrix(0, 0,
+                      static_cast<float>(target_width),
+                      static_cast<float>(target_height));
 
   text_renderer = std::make_unique<GLAtlasManager>();
   text_renderer->init();
